# Loading all the libraries
library("dplyr")
library("ggplot2")
library("binom")
library("harmonicmeanp")
library("lme4")

# Setting the working directory to the folder where all the data files are saved
setwd("/Volumes/GoogleDrive/My Drive/Research/Current Projects/Temporal coherence MS/Biology Letters/Data/")

## Sequenctial analysis for each test

# TEST 1
# Reading the raw data file obtained from Test 1
test1 <- read.csv("Test1_50vs25pps.csv",header = T, check.names = F)
test1 <- test1 %>% filter(!Choice == "NR") #eliminating no responses
test1$Choice <- as.numeric(as.character(test1$Choice))
test1 <- test1%>% mutate(Rel_amp=factor(Rel_amp), Amp=factor(Amp), Frog_ID = factor(Frog_ID))

# Analyzing the data to obtain proportion of females responding to each of the 12 stimulus condition
test1_group <- test1 %>% group_by(Rel_amp, Amp)
summary_test1 <- test1_group %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
binomial.test1 <- binom.exact(summary_test1$Choice,summary_test1$N) %>% mutate(Rel_amp = summary_test1$Rel_amp) %>% mutate(Amp = summary_test1$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals
binomial.test1$Rel_amp <- factor(binomial.test1$Rel_amp, levels = c(0,-5,-11))
binomial.test1$Amp <- factor(binomial.test1$Amp, levels = c(55,65,75,85))

# Analyzing the data to obtain proportion of females responding to each absolute amplitude when pooled across levels of relative amplitude
test1_group2 <- test1 %>% group_by(Amp)
summary_test1_2 <- test1_group2 %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
binomial.test1_2 <- binom.exact(summary_test1_2$Choice,summary_test1_2$N) %>% mutate(Amp = summary_test1_2$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals
binomial.test1_2$Amp <- factor(binomial.test1_2$Amp, levels = c(55,65,75,85))

# Plotting the proportion of females chossing coherent 50 pps over 25 pps
plot.test1 <- ggplot(binomial.test1_2, aes(x = Amp, y = mean))  +
  geom_bar(colour="black", stat = "identity", fill="#344c5c") +
  geom_errorbar(aes(ymin=lower, ymax=upper), linetype =1,width = 0.4) + 
  labs (x="Absolute level (dB SPL)", y = "P (50 pulses/s | Choice)") + theme_classic()+
  theme(axis.title.x=element_text(size=12),axis.title.y=element_text(size=12)) +
  geom_point(data=binomial.test1, size = 8, aes(colour = Rel_amp)) +
  scale_color_grey(start=0.4, end =0.8) + labs(color= "Relative amplitude") +  
  scale_y_continuous(breaks = seq(0,1.0, by = 0.25)) 

plot.test1 + coord_flip(ylim=c(0.5,1.0))

# Statistical analysis
# Performing two-tailed binomial test for all 12 conditions
binom_test <- function(a, b, p = 0.5) {binom.test(a, b, 0.5, alternative=
                                                    c("two.sided"), conf.level = 0.95)$p.value}
binomial.test1$pVal <- mapply(binom_test, binomial.test1$x, binomial.test1$n) # This gives p-values for all binomial tests
hmp.stat(binomial.test1$pVal, w = NULL) # This gives harmonic mean p-value

# Statistical effects of overall and relative amplitude
glmer1.1 <- glmer(Choice ~ (1|Frog_ID), 
                 data= test1, family="binomial") 
glmer1.2 <- glmer(Choice ~ Amp + Rel_amp + (1|Frog_ID), 
                 data= test1, family="binomial") # Cannot run this model because of complete separation


# TEST 2
# Reading the raw data file obtained from Test 2
test2 <- read.csv("Test2_50vs100pps.csv",header = T, check.names = F)
test2$Choice <- as.numeric(as.character(test2$Choice))
test2 <- test2%>% mutate(Rel_amp=factor(Rel_amp), Amp=factor(Amp), Frog_ID = factor(Frog_ID))

# Analyzing the data to obtain proportion of females responding to each of the 12 stimulus condition
test2_group <- test2 %>% group_by(Rel_amp, Amp)
summary_test2 <- test2_group %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
binomial.test2 <- binom.exact(summary_test2$Choice,summary_test2$N) %>% mutate(Rel_amp = summary_test2$Rel_amp) %>% mutate(Amp = summary_test2$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals
binomial.test2$Rel_amp <- factor(binomial.test2$Rel_amp, levels = c(0,-5,-11))
binomial.test2$Amp <- factor(binomial.test2$Amp, levels = c(55,65,75,85))

# Analyzing the data to obtain proportion of females responding to each absolute amplitude when pooled across levels of relative amplitude
test2_group2 <- test2 %>% group_by(Amp)
summary_test2_2 <- test2_group2 %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
binomial.test2_2 <- binom.exact(summary_test2_2$Choice,summary_test2_2$N) %>% mutate(Amp = summary_test2_2$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals
binomial.test2_2$Amp <- factor(binomial.test2_2$Amp, levels = c(55,65,75,85))

# Plotting the proportion of females chossing coherent 50 pps over 25 pps
plot.test2 <- ggplot(binomial.test2_2, aes(x = Amp, y = mean))  +
  geom_bar(colour="black", stat = "identity", fill="#344c5c") +
  geom_errorbar(aes(ymin=lower, ymax=upper), linetype =1,width = 0.4) + 
  labs (x="Absolute level (dB SPL)", y = "P (50 pulses/s | Choice)") + theme_classic()+
  theme(axis.title.x=element_text(size=12),axis.title.y=element_text(size=12)) +
  geom_point(data=binomial.test2, size = 8, aes(colour = Rel_amp)) +
  scale_color_grey(start=0.4, end =0.8) + labs(color= "Relative amplitude") +  
  scale_y_continuous(breaks = seq(0,1.0, by = 0.25)) 

plot.test2 + coord_flip(ylim=c(0.5,1.0))

# Statistical analysis
# Performing two-tailed binomial test for all 12 conditions
binom_test <- function(a, b, p = 0.5) {binom.test(a, b, 0.5, alternative=
                                                    c("two.sided"), conf.level = 0.95)$p.value}
binomial.test2$pVal <- mapply(binom_test, binomial.test2$x, binomial.test2$n) # This gives p-values for all binomial tests
hmp.stat(binomial.test2$pVal, w = NULL) # This gives harmonic mean p-value

# Statistical effects of overall and relative amplitude
glmer2.1 <- glmer(Choice ~ (1|Frog_ID), 
                  data= test2, family="binomial") # Cannot run this model because of complete separation
glmer2.2 <- glmer(Choice ~ Amp + Rel_amp + (1|Frog_ID), 
                 data= test2, family="binomial") # Cannot run this model because of complete separation

# TEST 3
# Reading the raw data file obtained from Test 3
test3 <- read.csv("Test3_50vs100pps.csv",header = T, check.names = F)
test3 <- test3 %>% filter(!Choice == "NR") #eliminating no responses
test3$Choice <- as.numeric(as.character(test3$Choice))
test3 <- test3%>% mutate(Rel_amp=factor(Rel_amp), Amp=factor(Amp), Frog_ID = factor(Frog_ID))

# Analyzing the data to obtain proportion of females responding to each of the 12 stimulus condition
test3_group <- test3 %>% group_by(Rel_amp, Amp)
summary_test3 <- test3_group %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
summary_test3 <- summary_test3 %>% mutate(Choice_100 = N-Choice) # Because choice as 1 was coded as response to 50 pps, Choice_100 was made to indicate the # of females choosing 100 over 50 pps
binomial.test3 <- binom.exact(summary_test3$Choice_100,summary_test3$N) %>% mutate(Rel_amp = summary_test3$Rel_amp) %>% mutate(Amp = summary_test3$Amp) # "Mean" gives proportion of females choosing 100 pps and lower and upper bounds are exact binomial conf intervals
binomial.test3$Rel_amp <- factor(binomial.test3$Rel_amp, levels = c(0,-5,-11))
binomial.test3$Amp <- factor(binomial.test3$Amp, levels = c(55,65,75,85))

binomial.test3_50pps <- binom.exact(summary_test3$Choice,summary_test3$N) %>% mutate(Rel_amp = summary_test3$Rel_amp) %>% mutate(Amp = summary_test3$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals

# Analyzing the data to obtain proportion of females responding to each absolute amplitude when pooled across levels of relative amplitude
test3_group2 <- test3%>% group_by(Amp)
summary_test3_2 <- test3_group2 %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
summary_test3_2 <- summary_test3_2 %>% mutate(Choice_100 = N-Choice) # Because choice as 1 was coded as response to 50 pps, Choice_100 was made to indicate the # of females choosing 100 over 50 pps
binomial.test3_2 <- binom.exact(summary_test3_2$Choice_100,summary_test3_2$N) %>% mutate(Amp = summary_test3_2$Amp) # "Mean" gives proportion of females choosing 100 pps and lower and upper bounds are exact binomial conf intervals
binomial.test3_2$Amp <- factor(binomial.test3_2$Amp, levels = c(55,65,75,85))

# Plotting the proportion of females chossing coherent 50 pps over 25 pps
plot.test3 <- ggplot(binomial.test3_2, aes(x = Amp, y = mean))  +
  geom_bar(colour="black", stat = "identity", fill="#344c5c") +
  geom_errorbar(aes(ymin=lower, ymax=upper), linetype =1,width = 0.4) + 
  labs (x="Absolute level (dB SPL)", y = "P (100 pulses/s | Choice)") + theme_classic()+
  theme(axis.title.x=element_text(size=12),axis.title.y=element_text(size=12)) +
  geom_point(data=binomial.test3, size = 8, aes(colour = Rel_amp)) +
  scale_color_grey(start=0.4, end =0.8) + labs(color= "Relative amplitude") +  
  scale_y_continuous(breaks = seq(0,1.0, by = 0.25)) 

plot.test3 + coord_flip(ylim=c(0.5,1.0)) 

# Statistical analysis
# Performing two-tailed binomial test for all 12 conditions
binom_test <- function(a, b, p = 0.5) {binom.test(a, b, 0.5, alternative=
                                                    c("two.sided"), conf.level = 0.95)$p.value}
binomial.test3$pVal <- mapply(binom_test, binomial.test3$x, binomial.test3$n) # This gives p-values for all binomial tests
hmp.stat(binomial.test3$pVal, w = NULL) # This gives harmonic mean p-value

# Statistical effects of overall and relative amplitude
glmer3.1 <- glmer(Choice ~ (1|Frog_ID), 
                  data= test3, family="binomial")
glmer3.2 <- glmer(Choice ~ Amp + Rel_amp + (1|Frog_ID), 
                  data= test3, family="binomial") 
anova(glmer3.1,glmer3.2)

# TEST 4
# Reading the raw data file obtained from Test 4
test4 <- read.csv("Test4_50vs100pps.csv",header = T, check.names = F)
test4 <- test4 %>% filter(!Choice == "NR") #eliminating no responses
test4$Choice <- as.numeric(as.character(test4$Choice))
test4 <- test4%>% mutate(Rel_amp=factor(Rel_amp), Amp=factor(Amp), Frog_ID = factor(Frog_ID))

# Analyzing the data to obtain proportion of females responding to each of the 12 stimulus condition
test4_group <- test4 %>% group_by(Rel_amp, Amp)
summary_test4 <- test4_group %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
binomial.test4 <- binom.exact(summary_test4$Choice,summary_test4$N) %>% mutate(Rel_amp = summary_test4$Rel_amp) %>% mutate(Amp = summary_test4$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals
binomial.test4$Rel_amp <- factor(binomial.test4$Rel_amp, levels = c(0,-5,-11))
binomial.test4$Amp <- factor(binomial.test4$Amp, levels = c(55,65,75,85))

# Analyzing the data to obtain proportion of females responding to each absolute amplitude when pooled across levels of relative amplitude
test4_group2 <- test4%>% group_by(Amp)
summary_test4_2 <- test4_group2 %>% summarize(Choice=sum(Choice, na.rm=F), N = n()) # The factor "Choice" gives the total number of females choosing 50 pps over 25 pps and N gives total females who made a choice
binomial.test4_2 <- binom.exact(summary_test4_2$Choice,summary_test4_2$N) %>% mutate(Amp = summary_test4_2$Amp) # "Mean" gives proportion of females choosing 50 pps and lower and upper bounds are exact binomial conf intervals
binomial.test4_2$Amp <- factor(binomial.test4_2$Amp, levels = c(55,65,75,85))

# Plotting the proportion of females chossing coherent 50 pps over 25 pps
plot.test4 <- ggplot(binomial.test4_2, aes(x = Amp, y = mean))  +
  geom_bar(colour="black", stat = "identity", fill="#344c5c") +
  geom_errorbar(aes(ymin=lower, ymax=upper), linetype =1,width = 0.4) + 
  labs (x="Absolute level (dB SPL)", y = "P (50 pulses/s | Choice)") + theme_classic()+
  theme(axis.title.x=element_text(size=12),axis.title.y=element_text(size=12)) +
  geom_point(data=binomial.test4, size = 8, aes(colour = Rel_amp)) +
  scale_color_grey(start=0.4, end =0.8) + labs(color= "Relative amplitude") +  
  scale_y_continuous(breaks = seq(0,1.0, by = 0.25)) 

plot.test4 + coord_flip(ylim=c(0.5,1.0))

# Statistical analysis
# Performing two-tailed binomial test for all 12 conditions
binom_test <- function(a, b, p = 0.5) {binom.test(a, b, 0.5, alternative=
                                                    c("two.sided"), conf.level = 0.95)$p.value}
binomial.test4$pVal <- mapply(binom_test, binomial.test4$x, binomial.test4$n) # This gives p-values for all binomial tests
hmp.stat(binomial.test4$pVal, w = NULL) # This gives harmonic mean p-value

# Statistical effects of overall and relative amplitude
glmer4.1 <- glmer(Choice ~ (1|Frog_ID), 
                  data= test4, family="binomial")
glmer4.2 <- glmer(Choice ~ Amp + Rel_amp + (1|Frog_ID), 
                  data= test4, family="binomial") 
anova(glmer4.1,glmer4.2)
